summaryrefslogtreecommitdiff
path: root/kafka/admin/client.py
diff options
context:
space:
mode:
Diffstat (limited to 'kafka/admin/client.py')
-rw-r--r--kafka/admin/client.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/kafka/admin/client.py b/kafka/admin/client.py
index 63a0f3b..fd4d661 100644
--- a/kafka/admin/client.py
+++ b/kafka/admin/client.py
@@ -1209,7 +1209,7 @@ class KafkaAdminClient(object):
:param response: an OffsetFetchResponse.
:return: A dictionary composed of TopicPartition keys and
- OffsetAndMetada values.
+ OffsetAndMetadata values.
"""
if response.API_VERSION <= 3:
@@ -1223,7 +1223,7 @@ class KafkaAdminClient(object):
.format(response))
# transform response into a dictionary with TopicPartition keys and
# OffsetAndMetada values--this is what the Java AdminClient returns
offsets = {}
for topic, partitions in response.topics:
for partition, offset, metadata, error_code in partitions:
@@ -1223,7 +1223,7 @@ class KafkaAdminClient(object):
.format(response))
# transform response into a dictionary with TopicPartition keys and
- # OffsetAndMetada values--this is what the Java AdminClient returns
+ # OffsetAndMetadata values--this is what the Java AdminClient returns
offsets = {}
for topic, partitions in response.topics: